@@ -4,10 +4,10 @@ use crate::mlp::{
 };
 
 use link_cache::LinkCache;
-use num_derive::{FromPrimitive, ToPrimitive};
 use num_traits::FromPrimitive;
 use parking_lot::Mutex;
 
+
 use rpc::Mumble;
 use std::{
     collections::BTreeMap,
@@ -16,7 +16,7 @@ use std::{
 };
 use tonic::transport::Server;
 
-use super::cross_platform::cmltypes::CMumbleLink;
+use super::cross_platform::{cmltypes::CMumbleLink, MLRequestCode};
 
 type MLmap = BTreeMap<String, LinkCache>;
 
@@ -34,13 +34,6 @@ pub struct Engine {
     pub socket_addr: SocketAddr,
 }
 
-#[derive(Debug, Clone, Copy, FromPrimitive, ToPrimitive)]
-#[repr(u8)]
-enum MLRequestCode {
-    Nothing,
-    CML,
-    WD,
-}
 
 impl Engine {
     pub fn create(ip: IpAddr, port: u16) -> anyhow::Result<Self> {
