@@ -8,5 +8,27 @@
 //! It can multiple accessing data of multiple MumbleLinks, and allows multiple clients
 //! to request the data.
 
+pub mod cross_platform;
+
+pub mod mlp {
+    tonic::include_proto!("mlp");
+}
+
+#[cfg(target_os = "windows")]
 pub mod engine;
-pub mod mlp;
+
+/*
+Ctypes -> clink, context,
+            from, from
+usefulT -> umlink (umctx)
+
+CacheT -> LinkCache
+
+Multiple -> MlMap
+
+Concurrent -> Mutex, Arc
+
+udp -> async, sync
+grpc -> async
+
+*/
